@@ -1,14 +1,12 @@
 # flake8: noqa
-# type: ignore
 __author__ = "Akio Taniguchi"
-__version__ = "0.4.0"
+__version__ = "0.5.0"
 
 
 # submodules
-from . import article
 from . import apps
+from . import article
 from . import cli
 from . import constants
-from . import detex
 from . import search
 from . import translate
